import { Stack, StackProps } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Represents the properties for the ImageBuilderTestStack class.
 * @interface
 * extends StackProps
 * @property {string} vpcCidr - The CIDR block for the VPC.
 * @property {string} version - The version of the image recipe to use.
 * @property {string[]} distributionAccountIds - The account IDs of the accounts that will receive the image.
 * @property {string[]} distributionRegions - The regions of the accounts that will receive the image.
 */
export interface ImageBuilderTestStackProps extends StackProps {
    distributionKmsKeyAlias?: string;
    debugImagePipeline?: boolean;
    vpcCidr: string;
    version?: string;
    distributionAccountIds?: string[];
    distributionRegions?: string[];
}
/**
 * Represents a CloudFormation stack for creating an image builder test pipeline.
 */
export declare class ImageBuilderTestStack extends Stack {
    constructor(scope: Construct, id: string, props: ImageBuilderTestStackProps);
}
